@@ -13,6 +13,7 @@
 
 # You should have received a copy of the GNU Lesser General Public License along with ActionTree.  If not, see <http://www.gnu.org/licenses/>.
 
+import multiprocessing
 import threading
 import time
 
@@ -111,6 +112,8 @@ class Action:
         :param int jobs: number of actions to execute in parallel
         :param bool keepGoing: if True, then :meth:`execute` does not stop on first failure, but executes as many dependencies as possible.
         """
+        if jobs <= 0:
+            jobs = multiprocessing.cpu_count() + 1
         self.__resetBeforeExecution()
         self.__doExecute(jobs, keepGoing)
 
@@ -147,12 +150,12 @@ class Action:
             action.beginTime = Action._time()
             try:
                 action.__execute()
-            except Exception, e:
+            except Exception as e:
                 with condition:
                     action.__status = Action.Failed
                     exceptions.append(e)
                     if not keepGoing and action is not self:
-                        self.__status = Action.Canceled
+                        self.__cancelAction(self)
             finally:
                 action.endTime = Action._time()
             with condition:
@@ -187,7 +190,7 @@ class Action:
 
     def __prepareExecution(self, action):
         if any(d.__isFailure() for d in action.__dependencies):
-            action.__status = Action.Canceled
+            self.__cancelAction(action)
             return False
         else:
             action.__status = Action.__Executing
@@ -197,7 +200,12 @@ class Action:
         for dependency in self.__dependencies:
             dependency.__markCanceledActions()
         if not self.__isFinished():
-            self.__status = Action.Canceled
+            self.__cancelAction(self)
+
+    def __cancelAction(self, action):
+        action.__status = Action.Canceled
+        action.beginTime = Action._time()
+        action.endTime = action.beginTime
 
     def __isFinished(self):
         return self.__status in [Action.Successful, Action.Failed, Action.Canceled]
